OpaqueError

Struct OpaqueError 

pub struct OpaqueError(/* private fields */);
Rarely will you need OpaqueError, it can however be a useful last-resort in case you get weird higher-rank Lifetime issues…

Such lifetime issues often arise when using BoxError directly as the error for a BoxService.

Implementations

Source

impl OpaqueError

pub fn from_static_str(e: &'static str) -> Self

Create an opaque error from a static str.

Use this instead of "msg".context() or some other method that turns it into a BoxError… Because the std rust library turns this into a String otherwise…

pub fn into_box_error(self) -> BoxError

Unwrap into the inner BoxError.

OpaqueError is a transparent BoxError wrapper, so this is free. This shadows the generic into_box_error added by ErrorExt trait.